/*
 * Copyright (C) 2002-2003 chik, hiranaka
 * For license terms, see the file COPYING in this directory.
 */

// StrTok.cpp: CStrTok NX̃Cve[V
//
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "StrTok.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// \z/
//////////////////////////////////////////////////////////////////////

CStrTok::CStrTok()
{

}

CStrTok::~CStrTok()
{

}

const char* CStrTok::Tokenize(char *in, char *delimiter)
{
	char *start;
	char *end;

	if(in != NULL) m_pStart = in;
	start = m_pStart;

	end = strstr(start, delimiter);
	if(end == NULL)
	{
		m_pStart = start+strlen(start);
		return start;
	}
	else *end ='\0';

	m_pStart = end+1;
	return start;
}
